# nxs-analysis-tools

## Overview

nxs-analysis-tools is a toolkit for managing and analyzing single crystal scattering datasets that have already been processed and stored in the NeXus file format (.nxs). Some notable functionalities are facile plotting of arbitrary reciprocal space planes with the correct angle between axes, data symmetrization, an all-in-one class for difference pair distribution function analysis (delta-PDF), data rotations, linecuts, and rebinning. Beyond this, if your data is from the Cornell High Energy Synchrotron Source (CHESS) beamline ID4B (or, at least formatted similarly), then this package provides a way to analyze an entire temperature series of scattering data at once, allowing for easier analysis of temperature-dependent features in the data.
## Contents

```{toctree}
---
maxdepth: 2
---
examples/index
api
license
```

## License

This project is {doc}`licensed <license>` under the [MIT License](https://opensource.org/licenses/MIT).
